@@ -11,7 +11,8 @@
 from meutils.pipe import *
 
 
-def extract_data(p, encoding='utf-8', start_func=lambda x: x.startswith('create table'), end_func=lambda x: x.startswith('tablespace')):
+def extract_data(p, encoding='utf-8', start_func=lambda x: x.startswith('create table'),
+                 end_func=lambda x: x.startswith('tablespace')):
     flag = False
     data_map = {}
     with open(p, encoding=encoding) as f:
@@ -28,11 +29,14 @@ def extract_data(p, encoding='utf-8', start_func=lambda x: x.startswith('create
     return data_map
 
 
-def main(ipath, opath=None, encoding='utf-8'):
+def main(ipath, opath=None, encoding='GB18030'):
     p = Path(ipath)
     if opath is None:
         opath = p.parent / f"{p.name}.tsv"
 
+    logger.info(f"输入路径: {p}")
+    logger.info(f"输出路径: {opath}")
+
     d = extract_data(p, encoding)
     dd = {i: j[1:-2] for i, j in d.items()}
 
